
# Slot: object




URI: [biolink:entity_to_disease_association_object](https://w3id.org/biolink/vocab/entity_to_disease_association_object)

## Domain and Range

[EntityToDiseaseAssociation](EntityToDiseaseAssociation.md) ->  <sub>REQ</sub> [Disease](Disease.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [EntityToDiseaseAssociation](EntityToDiseaseAssociation.md)
